Struct http_types::auth::WwwAuthenticate [−][src]
pub struct WwwAuthenticate { /* fields omitted */ }Define the authentication method that should be used to gain access to a resource.
Specifications
Implementation Notes
This implementation only encodes and parses a single authentication method, further authorization methods are ignored. It also always passes the utf-8 encoding flag.
Examples
use http_types::Response; use http_types::auth::{AuthenticationScheme, WwwAuthenticate}; let scheme = AuthenticationScheme::Basic; let realm = "Access to the staging site"; let authz = WwwAuthenticate::new(scheme, realm.into()); let mut res = Response::new(200); authz.apply(&mut res); let authz = WwwAuthenticate::from_headers(res)?.unwrap(); assert_eq!(authz.scheme(), AuthenticationScheme::Basic); assert_eq!(authz.realm(), realm);
Implementations
impl WwwAuthenticate[src]
impl WwwAuthenticate[src]pub fn new(scheme: AuthenticationScheme, realm: String) -> Self[src]
Create a new instance of WwwAuthenticate.
pub fn from_headers(headers: impl AsRef<Headers>) -> Result<Option<Self>>[src]
Create a new instance from headers.
pub fn apply(&self, headers: impl AsMut<Headers>)[src]
Sets the header.
pub fn name(&self) -> HeaderName[src]
Get the HeaderName.
pub fn value(&self) -> HeaderValue[src]
Get the HeaderValue.
pub fn scheme(&self) -> AuthenticationScheme[src]
Get the authorization scheme.
pub fn set_scheme(&mut self, scheme: AuthenticationScheme)[src]
Set the authorization scheme.
pub fn realm(&self) -> &str[src]
Get the authorization realm.
pub fn set_realm(&mut self, realm: String)[src]
Set the authorization realm.