Module cookies

Module cookies 

Available on crate feature cookies only.
HTTP cookies.

Structs

Cookie
Representation of an HTTP cookie.
CookieBuilder
Structure that follows the builder pattern for building Cookie structs.
CookieJar
A collection of cookies that tracks its modifications.
Delta
Iterator over the changes to a cookie jar.
EncodedCookiepercent-encode
Wrapper around Cookie whose Display implementation percent-encodes the cookie’s name and value.
Iter
Iterator over all of the cookies in a jar.
Keyprivate or signed
A cryptographic master key for use with Signed and/or Private jars.
PrivateJarprivate
A child cookie jar that provides authenticated encryption for its cookies.
SignedJarsigned
A child cookie jar that authenticates its cookies.

Enums

ParseError
Enum corresponding to a parsing error.
SameSite
The SameSite cookie attribute.