Struct http_types::trailers::Sender [−][src]
pub struct Sender { /* fields omitted */ }The sending half of a channel to send trailers.
Unlike async_channel::Sender the send method on this type can only be
called once, and cannot be cloned. That’s because only a single instance of
Trailers should be created.
Implementations