Struct http_types::upgrade::Sender [−][src]
pub struct Sender { /* fields omitted */ }The sending half of a channel to send an upgraded connection.
Unlike async_channel::Sender the send method on this type can only be
called once, and cannot be cloned. That’s because only a single instance of
Connection should be created.
Implementations
impl Sender[src]
impl Sender[src]pub async fn send(self, conn: Connection)[src]
Send a Connection.
The channel will be consumed after having sent the connection.